[mupen64plus-ui-console] 91/172: Imported Upstream version 1.99.5

Sven Eckelmann ecsv-guest at moszumanska.debian.org
Thu Nov 26 06:07:35 UTC 2015


This is an automated email from the git hooks/post-receive script.

ecsv-guest pushed a commit to branch armhf_test
in repository mupen64plus-ui-console.

commit 0222e42a4b68c9a80a471d7eda7a165dbe6333c1
Author: Sven Eckelmann <sven at narfation.org>
Date:   Sun Mar 11 12:40:38 2012 +0100

    Imported Upstream version 1.99.5
---
 README                                    | 28 ++++++++++-----------
 RELEASE                                   |  7 ++++++
 projects/msvc8/mupen64plus-ui-console.sln |  7 ++++++
 src/core_interface.c                      |  6 +++++
 src/core_interface.h                      |  2 ++
 src/main.c                                | 42 +++++++++++++++++++++++++++----
 src/version.h                             |  2 +-
 7 files changed, 74 insertions(+), 20 deletions(-)

diff --git a/README b/README
index 0895ef5..6c755dd 100644
--- a/README
+++ b/README
@@ -13,14 +13,15 @@ Run 'mupen64plus --help' for a complete list of command-line options:
 Usage: mupen64plus [parameter(s)] [romfile]
 
 Parameters:
-    --noosd               : disable onscreen display.
-    --osd                 : enable onscreen display.
+    --noosd               : disable onscreen display
+    --osd                 : enable onscreen display
     --fullscreen          : use fullscreen display mode
     --windowed            : use windowed display mode
     --resolution (res)    : display resolution (640x480, 800x600, 1024x768, etc)
+    --nospeedlimit        : disable core speed limiter (should be used with dummy audio plugin)
     --cheats (cheat-spec) : enable or list cheat codes for the given rom file
     --corelib (filepath)  : use core library (filepath) (can be only filename or full path)
-    --configdir (dir)     : force configation directory to (dir); should contain mupen64plus.cfg
+    --configdir (dir)     : force configation directory to (dir); should contain mupen64plus.conf
     --datadir (dir)       : search for shared data files (.ini files, languages, etc) in (dir)
     --plugindir (dir)     : search for plugins in (dir)
     --sshotdir (dir)      : set screenshot directory to (dir)
@@ -33,20 +34,19 @@ Parameters:
     --set (param-spec)    : set a configuration variable, format: ParamSection[ParamName]=Value
     --core-compare-send   : use the Core Comparison debugging feature, in data sending mode
     --core-compare-recv   : use the Core Comparison debugging feature, in data receiving mode
-    --saveoptions         : save the given command-line options in configuration file for future
+    --nosaveoptions       : do not save the given command-line options in configuration file
     --verbose             : print lots of information
     --help                : see this help message
 
-    (plugin-spec):
-        (pluginname)          : filename (without path) of plugin to find in plugin directory
-        (pluginpath)          : full path and filename of plugin
-        'dummy'               : use dummy plugin
-
-    (cheat-spec):
-        'list'                : show all of the available cheat codes
-        'all'                 : enable all of the available cheat codes
-        (codelist)            : a comma-separated list of cheat code numbers to enable,
-                                with dashes to use code variables (ex 1-2 to use cheat 1 option 2)
+(plugin-spec):
+    (pluginname)          : filename (without path) of plugin to find in plugin directory
+    (pluginpath)          : full path and filename of plugin
+    'dummy'               : use dummy plugin
 
+(cheat-spec):
+    'list'                : show all of the available cheat codes
+    'all'                 : enable all of the available cheat codes
+    (codelist)            : a comma-separated list of cheat code numbers to enable,
+                            with dashes to use code variables (ex 1-2 to use cheat 1 option 2)
 
 
diff --git a/RELEASE b/RELEASE
index a0f856d..ab52f5e 100644
--- a/RELEASE
+++ b/RELEASE
@@ -1,6 +1,13 @@
 Mupen64Plus-UI-Console RELEASE
 ------------------------------
 
+Mupen64Plus-UI-Console Front-End v1.99.5 - March 10, 2012
+---------------------------------------------------------
+ - New option to disable internal core speed limiter (for benchmarking)
+ - Updated Console-UI front-end for new Mupen64plus 2.0 API versioning
+ - Added config version number for UI-Console section
+ - makefile fixes and improvements
+
 Mupen64Plus-UI-Console Front-End v1.99.4 - November 22, 2010
 ------------------------------------------------------------
  - add some parameter checking for --emumode option
diff --git a/projects/msvc8/mupen64plus-ui-console.sln b/projects/msvc8/mupen64plus-ui-console.sln
index 1b39d4e..08eb380 100644
--- a/projects/msvc8/mupen64plus-ui-console.sln
+++ b/projects/msvc8/mupen64plus-ui-console.sln
@@ -1,6 +1,13 @@
 Microsoft Visual Studio Solution File, Format Version 9.00
 # Visual Studio 2005
 Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "mupen64plus-ui-console", "mupen64plus-ui-console.vcproj", "{0E29D9F8-C675-4D21-AF16-AA80EDDB264E}"
+	ProjectSection(ProjectDependencies) = postProject
+		{96969748-EA54-43FC-8103-A346E9AD98E7} = {96969748-EA54-43FC-8103-A346E9AD98E7}
+		{7D4AFF6A-B7D9-4C25-975A-038B8079098E} = {7D4AFF6A-B7D9-4C25-975A-038B8079098E}
+		{92D3FEB9-2129-41C5-8577-BCD7D961EF41} = {92D3FEB9-2129-41C5-8577-BCD7D961EF41}
+		{7F3178D0-0E2E-471B-9160-69F0354F9DE9} = {7F3178D0-0E2E-471B-9160-69F0354F9DE9}
+		{2EC7CEE3-C7A7-4F2E-B2C8-4DF6AFEC3E9A} = {2EC7CEE3-C7A7-4F2E-B2C8-4DF6AFEC3E9A}
+	EndProjectSection
 EndProject
 Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "mupen64plus-core", "..\..\..\mupen64plus-core\projects\msvc8\mupen64plus-core.vcproj", "{92D3FEB9-2129-41C5-8577-BCD7D961EF41}"
 EndProject
diff --git a/src/core_interface.c b/src/core_interface.c
index 05bc9fe..d15d179 100644
--- a/src/core_interface.c
+++ b/src/core_interface.c
@@ -57,6 +57,8 @@ ptr_CoreCheatEnabled    CoreCheatEnabled = NULL;
 /* definitions of pointers to Core config functions */
 ptr_ConfigListSections     ConfigListSections = NULL;
 ptr_ConfigOpenSection      ConfigOpenSection = NULL;
+ptr_ConfigDeleteSection    ConfigDeleteSection = NULL;
+ptr_ConfigSaveSection      ConfigSaveSection = NULL;
 ptr_ConfigListParameters   ConfigListParameters = NULL;
 ptr_ConfigSaveFile         ConfigSaveFile = NULL;
 ptr_ConfigSetParameter     ConfigSetParameter = NULL;
@@ -221,6 +223,8 @@ m64p_error AttachCoreLib(const char *CoreLibFilepath)
     /* get function pointers to the configuration functions */
     ConfigListSections = (ptr_ConfigListSections) osal_dynlib_getproc(CoreHandle, "ConfigListSections");
     ConfigOpenSection = (ptr_ConfigOpenSection) osal_dynlib_getproc(CoreHandle, "ConfigOpenSection");
+    ConfigDeleteSection = (ptr_ConfigDeleteSection) osal_dynlib_getproc(CoreHandle, "ConfigDeleteSection");
+    ConfigSaveSection = (ptr_ConfigSaveSection) osal_dynlib_getproc(CoreHandle, "ConfigSaveSection");
     ConfigListParameters = (ptr_ConfigListParameters) osal_dynlib_getproc(CoreHandle, "ConfigListParameters");
     ConfigSaveFile = (ptr_ConfigSaveFile) osal_dynlib_getproc(CoreHandle, "ConfigSaveFile");
     ConfigSetParameter = (ptr_ConfigSetParameter) osal_dynlib_getproc(CoreHandle, "ConfigSetParameter");
@@ -287,6 +291,8 @@ m64p_error DetachCoreLib(void)
 
     ConfigListSections = NULL;
     ConfigOpenSection = NULL;
+    ConfigDeleteSection = NULL;
+    ConfigSaveSection = NULL;
     ConfigListParameters = NULL;
     ConfigSetParameter = NULL;
     ConfigGetParameter = NULL;
diff --git a/src/core_interface.h b/src/core_interface.h
index 3f60ae3..295daae 100644
--- a/src/core_interface.h
+++ b/src/core_interface.h
@@ -53,6 +53,8 @@ extern ptr_CoreCheatEnabled    CoreCheatEnabled;
 /* declarations of pointers to Core config functions */
 extern ptr_ConfigListSections     ConfigListSections;
 extern ptr_ConfigOpenSection      ConfigOpenSection;
+extern ptr_ConfigDeleteSection    ConfigDeleteSection;
+extern ptr_ConfigSaveSection      ConfigSaveSection;
 extern ptr_ConfigListParameters   ConfigListParameters;
 extern ptr_ConfigSaveFile         ConfigSaveFile;
 extern ptr_ConfigSetParameter     ConfigSetParameter;
diff --git a/src/version.h b/src/version.h
index 47bfc6d..d26973d 100644
--- a/src/version.h
+++ b/src/version.h
@@ -27,7 +27,7 @@
 #define VERSION_H
 
 #define CONSOLE_UI_NAME    "Mupen64Plus Console User-Interface"
-#define CONSOLE_UI_VERSION 0x016304
+#define CONSOLE_UI_VERSION 0x016305
 #define CORE_API_VERSION   0x20001
 #define CONFIG_API_VERSION 0x20000
 

diff --git a/src/main.c b/src/main.c
index f82bfcb..0568deb 100644
--- a/src/main.c
+++ b/src/main.c
@@ -42,6 +42,9 @@
 #include "compare_core.h"
 #include "osal_preproc.h"
 
+/* Version number for UI-Console config section parameters */
+#define CONFIG_PARAM_VERSION     1.00
+
 /** global variables **/
 int    g_Verbose = 0;
 
@@ -62,7 +65,7 @@ static const char *l_ROMFilepath = NULL;       // filepath of ROM to load & run
 
 static int  *l_TestShotList = NULL;      // list of screenshots to take for regression test support
 static int   l_TestShotIdx = 0;          // index of next screenshot frame in list
-static int   l_SaveOptions = 0;          // save command-line options in configuration file
+static int   l_SaveOptions = 1;          // save command-line options in configuration file (enabled by default)
 static int   l_CoreCompareMode = 0;      // 0 = disable, 1 = send, 2 = receive
 
 static eCheatMode l_CheatMode = CHEAT_DISABLE;
@@ -111,6 +114,8 @@ static void FrameCallback(unsigned int FrameIndex)
 
 static m64p_error OpenConfigurationHandles(void)
 {
+    float fConfigParamsVersion;
+    int bSaveConfig = 0;
     m64p_error rval;
 
     /* Open Configuration sections for core library and console User Interface */
@@ -135,13 +140,40 @@ static m64p_error OpenConfigurationHandles(void)
         return rval;
     }
 
+    if ((*ConfigGetParameter)(l_ConfigUI, "Version", M64TYPE_FLOAT, &fConfigParamsVersion, sizeof(float)) != M64ERR_SUCCESS)
+    {
+        fprintf(stderr, "Warning: No version number in 'UI-Console' config section. Setting defaults.\n");
+        (*ConfigDeleteSection)("UI-Console");
+        (*ConfigOpenSection)("UI-Console", &l_ConfigUI);
+        bSaveConfig = 1;
+    }
+    else if (((int) fConfigParamsVersion) != ((int) CONFIG_PARAM_VERSION))
+    {
+        fprintf(stderr, "Warning: Incompatible version %.2f in 'UI-Console' config section: current is %.2f. Setting defaults.\n", fConfigParamsVersion, (float) CONFIG_PARAM_VERSION);
+        (*ConfigDeleteSection)("UI-Console");
+        (*ConfigOpenSection)("UI-Console", &l_ConfigUI);
+        bSaveConfig = 1;
+    }
+    else if ((CONFIG_PARAM_VERSION - fConfigParamsVersion) >= 0.0001f)
+    {
+        /* handle upgrades */
+        float fVersion = CONFIG_PARAM_VERSION;
+        ConfigSetParameter(l_ConfigUI, "Version", M64TYPE_FLOAT, &fVersion);
+        fprintf(stderr, "Info: Updating parameter set version in 'UI-Console' config section to %.2f\n", fVersion);
+        bSaveConfig = 1;
+    }
+
     /* Set default values for my Config parameters */
+    (*ConfigSetDefaultFloat)(l_ConfigUI, "Version", CONFIG_PARAM_VERSION,  "Mupen64Plus UI-Console config parameter set version number.  Please don't change");
     (*ConfigSetDefaultString)(l_ConfigUI, "PluginDir", OSAL_CURRENT_DIR, "Directory in which to search for plugins");
     (*ConfigSetDefaultString)(l_ConfigUI, "VideoPlugin", "mupen64plus-video-rice" OSAL_DLL_EXTENSION, "Filename of video plugin");
     (*ConfigSetDefaultString)(l_ConfigUI, "AudioPlugin", "mupen64plus-audio-sdl" OSAL_DLL_EXTENSION, "Filename of audio plugin");
     (*ConfigSetDefaultString)(l_ConfigUI, "InputPlugin", "mupen64plus-input-sdl" OSAL_DLL_EXTENSION, "Filename of input plugin");
     (*ConfigSetDefaultString)(l_ConfigUI, "RspPlugin", "mupen64plus-rsp-hle" OSAL_DLL_EXTENSION, "Filename of RSP plugin");
 
+    if (bSaveConfig && ConfigSaveSection != NULL) /* ConfigSaveSection was added in Config API v2.1.0 */
+        (*ConfigSaveSection)("UI-Console");
+
     return M64ERR_SUCCESS;
 }
 
@@ -196,7 +228,7 @@ static void printUsage(const char *progname)
            "    --set (param-spec)    : set a configuration variable, format: ParamSection[ParamName]=Value\n"
            "    --core-compare-send   : use the Core Comparison debugging feature, in data sending mode\n"
            "    --core-compare-recv   : use the Core Comparison debugging feature, in data receiving mode\n"
-           "    --saveoptions         : save the given command-line options in configuration file for future\n"
+           "    --nosaveoptions       : do not save the given command-line options in configuration file\n"
            "    --verbose             : print lots of information\n"
            "    --help                : see this help message\n\n"
            "(plugin-spec):\n"
@@ -499,9 +531,9 @@ static m64p_error ParseCommandLineFinal(int argc, const char **argv)
         {
             l_CoreCompareMode = 2;
         }
-        else if (strcmp(argv[i], "--saveoptions") == 0)
+        else if (strcmp(argv[i], "--nosaveoptions") == 0)
         {
-            l_SaveOptions = 1;
+            l_SaveOptions = 0;
         }
         else if (ArgsLeft == 0)
         {
@@ -687,7 +719,7 @@ int main(int argc, char *argv[])
     /* close the ROM image */
     (*CoreDoCommand)(M64CMD_ROM_CLOSE, 0, NULL);
 
-    /* save the configuration file again if --saveoptions was specified, to keep any updated parameters from the core/plugins */
+    /* save the configuration file again if --nosaveoptions was not specified, to keep any updated parameters from the core/plugins */
     if (l_SaveOptions)
         SaveConfigurationOptions();
 
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-games/mupen64plus-ui-console.git



More information about the Pkg-games-commits mailing list